# Generated by Django 4.2.15 on 2024-09-25 20:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0221_enterprisegroup_group_type_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='enterprisegroup',
            name='group_type',
            field=models.CharField(choices=[('budget', 'Budget'), ('flex', 'Flex')], default='flex', help_text='The type of enterprise group', max_length=20, verbose_name='Group Type'),
        ),
        migrations.AlterField(
            model_name='historicalenterprisegroup',
            name='group_type',
            field=models.CharField(choices=[('budget', 'Budget'), ('flex', 'Flex')], default='flex', help_text='The type of enterprise group', max_length=20, verbose_name='Group Type'),
        ),
    ]
