# Generated by Django 3.2.15 on 2022-09-28 16:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('integrated_channel', '0015_auto_20220718_2113'),
    ]

    operations = [
        migrations.AddField(
            model_name='contentmetadataitemtransmission',
            name='marked_for',
            field=models.CharField(blank=True, help_text='Flag marking a record as needing a form of transmitting', max_length=32, null=True),
        ),
    ]
