# Generated by Django 4.2.10 on 2024-06-14 08:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0213_populate_learner_portal_sidebar_content_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='enterprisecustomer',
            name='learner_portal_sidebar_content',
            field=models.TextField(blank=True, help_text='Text shown on the learner portal dashboard for customer specific purposes. Open HTML field.'),
        ),
        migrations.AlterField(
            model_name='historicalenterprisecustomer',
            name='learner_portal_sidebar_content',
            field=models.TextField(blank=True, help_text='Text shown on the learner portal dashboard for customer specific purposes. Open HTML field.'),
        ),
    ]
