# Generated by Django 3.2.23 on 2024-04-09 11:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('degreed2', '0027_auto_20240329_1537'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='degreed2enterprisecustomerconfiguration',
            name='client_id',
        ),
        migrations.RemoveField(
            model_name='degreed2enterprisecustomerconfiguration',
            name='client_secret',
        ),
    ]
