# Generated by Django 3.2.23 on 2024-06-04 10:46

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('blackboard', '0022_blackboardlearnerassessmentdatatransmissionaudit_is_transmitted_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='blackboardenterprisecustomerconfiguration',
            name='client_id',
        ),
        migrations.RemoveField(
            model_name='blackboardenterprisecustomerconfiguration',
            name='client_secret',
        ),
    ]
