# Generated by Django 2.2.13 on 2020-06-29 17:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0097_auto_20200619_1130'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecourseenrollment',
            name='saved_for_later',
            field=models.BooleanField(default=False, help_text='Specifies whether a user marked this course as saved for later in the learner portal.'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecourseenrollment',
            name='saved_for_later',
            field=models.BooleanField(default=False, help_text='Specifies whether a user marked this course as saved for later in the learner portal.'),
        ),
    ]
