# Generated by Django 3.2.12 on 2022-03-23 17:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('degreed2', '0008_degreed2learnerdatatransmissionaudit_course_completed'),
    ]

    operations = [
        migrations.AlterField(
            model_name='degreed2learnerdatatransmissionaudit',
            name='completed_timestamp',
            field=models.CharField(blank=True, help_text='yyyy-mm-ddTHH:MM:SS format. Can be left unset for audit records.', max_length=19, null=True),
        ),
    ]
