
{% extends 'enterprise/base.html' %}

{% load i18n static enterprise %}

{% block extrahead %}
  <script type="text/javascript" src="{% static 'js/vendor/jquery.cookie.js' %}"></script>
  <script type="text/javascript" src="{% static 'enterprise/js/enterprise_selection_page.js' %}"></script>
{% endblock %}

{% block contents %}
  <main>
    <div class="enterprise-container">
      <div class="select-enterprise-container">

          <h1 class="select-enterprise-title h2">{{ select_enterprise_message_title|safe }}</h1>
          <div class="select-enterprise-message">
            <p>{{ select_enterprise_message_subtitle|safe }}</p>
          </div>

          <form action="" method="POST" id="select-enterprise-form">
            {% csrf_token %}

            <div
              role="alert"
              aria-live="assertive"
              class="select-enterprise errorlist is-hidden"
              id="select-enterprise-form-error">
            </div>

            {% for field in form.visible_fields %}
              <div class="form-group">
              {{ field.label_tag }}
              {{ field.errors }}
              {{ field }}
              {{ field.help_text }}
              </div>
            {% endfor %}

            {% for hidden_field in form.hidden_fields %}
              <div>
              {{ hidden_field }}
              </div>
            {% endfor %}

            <button
              type="submit"
              class="background-input btn btn-primary"
              id="select-enterprise-submit">
              {% trans "Continue" %}
            </button>
            <span id="activate-progress-icon" class="icon fa fa-spinner fa-spin is-hidden" aria-hidden="true"></span>
          </form>

      </div>
    </div>
  </main>
{% endblock %}
