# Generated by Django 3.2.23 on 2024-03-12 15:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0202_enterprisegroup_applies_to_all_contexts_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisegroupmembership',
            name='activated_at',
            field=models.DateTimeField(blank=True, default=None, help_text='The moment at which the membership record is written with an Enterprise Customer User record.', null=True),
        ),
        migrations.AddField(
            model_name='historicalenterprisegroupmembership',
            name='activated_at',
            field=models.DateTimeField(blank=True, default=None, help_text='The moment at which the membership record is written with an Enterprise Customer User record.', null=True),
        ),
    ]
